@@ -159,7 +159,7 @@ static int parse_up_record(rnode* r)
 				}
 			}
 			// Make virtual keys or just store it
-			if (strcmp(n.name, "key") == 0) {
+			if (strcmp(n.name, "key") == 0 && *n.val != '(') {
 				char *key = (char *)au_unescape(n.val);
 				char *ptr = strtok_r(key, key_sep, &saved);
 				free(n.name);
